@@ -1,30 +1,46 @@
+{-# LANGUAGE FlexibleContexts #-}
 {-# LANGUAGE ViewPatterns #-}
 
 module HSE.All(
     module X,
-    ParseFlags(..), defaultParseFlags,
+    CppFlags(..), ParseFlags(..), defaultParseFlags,
     parseFlagsAddFixities, parseFlagsSetLanguage,
-    parseModuleEx, ParseError(..)
+    parseModuleEx, ParseError(..),
+    freeVars, vars, varss, pvars
     ) where
 
+import Language.Haskell.Exts.Util hiding (freeVars, Vars(..))
+import qualified Language.Haskell.Exts.Util as X
 import HSE.Util as X
 import HSE.Reduce as X
 import HSE.Type as X
-import HSE.Bracket as X
 import HSE.Match as X
 import HSE.Scope as X
-import HSE.FreeVars as X
 import Util
-import CmdLine
 import Data.Char
 import Data.List.Extra
 import Data.Maybe
 import Language.Preprocessor.Cpphs
+import Data.Set (Set)
 import qualified Data.Map as Map
+import qualified Data.Set as Set
 import System.IO.Extra
 import Data.Functor
 import Prelude
 
+vars :: FreeVars a => a -> [String]
+freeVars :: FreeVars a => a -> Set String
+varss, pvars :: AllVars a => a -> [String]
+vars  = Set.toList . Set.map prettyPrint . X.freeVars
+varss = Set.toList . Set.map prettyPrint . X.free . X.allVars
+pvars = Set.toList . Set.map prettyPrint . X.bound . X.allVars
+freeVars = Set.map prettyPrint . X.freeVars
+
+-- | What C pre processor should be used.
+data CppFlags
+    = NoCpp -- ^ No pre processing is done.
+    | CppSimple -- ^ Lines prefixed with @#@ are stripped.
+    | Cpphs CpphsOptions -- ^ The @cpphs@ library is used.
 
 -- | Created with 'defaultParseFlags', used by 'parseModuleEx'.
 data ParseFlags = ParseFlags
